==> jc-1.4.0.tar.gz: java/nio/charset/CoderResult__242.h <==
// final class java.nio.charset.CoderResult$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e128648a7063a6bd java_nio_charset_CoderResult__242
// @dep_class 14254178dbad6381 java_nio_charset_CoderResult__24Cache

// header file dependencies
// @dep_header java_nio_charset_CoderResult__24Cache

#include "java/nio/charset/CoderResult__24Cache.h"

#ifndef _JC_java_nio_charset_CoderResult__242_H_
#define _JC_java_nio_charset_CoderResult__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_charset_CoderResult$object;

// Typedefs
typedef struct _jc_java_nio_charset_CoderResult__242$sub_refs	_jc_java_nio_charset_CoderResult__242$sub_refs;
typedef struct _jc_java_nio_charset_CoderResult__242$sub_nonrefs	_jc_java_nio_charset_CoderResult__242$sub_nonrefs;
typedef struct _jc_java_nio_charset_CoderResult__242$refs	_jc_java_nio_charset_CoderResult__242$refs;
typedef struct _jc_java_nio_charset_CoderResult__242$nonrefs	_jc_java_nio_charset_CoderResult__242$nonrefs;
typedef struct _jc_java_nio_charset_CoderResult__242$object	_jc_java_nio_charset_CoderResult__242$object;

typedef const struct _jc_java_nio_charset_CoderResult__242$vmethods	_jc_java_nio_charset_CoderResult__242$vmethods;
typedef const struct _jc_java_nio_charset_CoderResult__242$vtable	_jc_java_nio_charset_CoderResult__242$vtable;
typedef const struct _jc_java_nio_charset_CoderResult__242$vtype	_jc_java_nio_charset_CoderResult__242$vtype;

// Constructors
extern void _jc_java_nio_charset_CoderResult__242$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_charset_CoderResult__242$object *);

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_java_nio_charset_CoderResult__242$method$make$f3cbfffb1f7afd3c(_jc_env *, struct _jc_java_nio_charset_CoderResult__242$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_CoderResult__242$method_info$make$f3cbfffb1f7afd3c;

// Virtual methods structure
struct _jc_java_nio_charset_CoderResult__242$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*make$f3cbfffb1f7afd3c)(_jc_env *, struct _jc_java_nio_charset_CoderResult__242$object *, jint);
};

// Vtable
struct _jc_java_nio_charset_CoderResult__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CoderResult__24Cache$vmethods	java_nio_charset_CoderResult__24Cache;
	_jc_java_nio_charset_CoderResult__242$vmethods	java_nio_charset_CoderResult__242;
};

// Vtype
struct _jc_java_nio_charset_CoderResult__242$vtype {
	_jc_type			type;
	_jc_java_nio_charset_CoderResult__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_CoderResult__242$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_CoderResult__242$refs {
    _jc_java_nio_charset_CoderResult__242$sub_refs	java_nio_charset_CoderResult__242;
    _jc_java_nio_charset_CoderResult__24Cache$sub_refs	java_nio_charset_CoderResult__24Cache;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_CoderResult__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_CoderResult__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CoderResult__24Cache$sub_nonrefs	java_nio_charset_CoderResult__24Cache;
    _jc_java_nio_charset_CoderResult__242$sub_nonrefs	java_nio_charset_CoderResult__242;
};

// Object instance structure
struct _jc_java_nio_charset_CoderResult__242$object {
	_jc_java_nio_charset_CoderResult__242$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_CoderResult__242$vtype	*vtype;
	_jc_java_nio_charset_CoderResult__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_CoderResult__242$vtype _jc_java_nio_charset_CoderResult__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_CoderResult__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_CoderResult__242$class_object;

#endif	/* _JC_java_nio_charset_CoderResult__242_H_ */

==> jc-1.4.6.tar.gz: java/nio/charset/CoderResult__242.h <==
// final class java.nio.charset.CoderResult$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e128648a7063a6bd java_nio_charset_CoderResult__242
// @dep_class 14254178dbad6381 java_nio_charset_CoderResult__24Cache

// header file dependencies
// @dep_header java_nio_charset_CoderResult__24Cache

#include "java/nio/charset/CoderResult__24Cache.h"

#ifndef _JC_java_nio_charset_CoderResult__242_H_
#define _JC_java_nio_charset_CoderResult__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_charset_CoderResult$object;

// Typedefs
typedef struct _jc_java_nio_charset_CoderResult__242$sub_refs	_jc_java_nio_charset_CoderResult__242$sub_refs;
typedef struct _jc_java_nio_charset_CoderResult__242$sub_nonrefs	_jc_java_nio_charset_CoderResult__242$sub_nonrefs;
typedef struct _jc_java_nio_charset_CoderResult__242$refs	_jc_java_nio_charset_CoderResult__242$refs;
typedef struct _jc_java_nio_charset_CoderResult__242$nonrefs	_jc_java_nio_charset_CoderResult__242$nonrefs;
typedef struct _jc_java_nio_charset_CoderResult__242$object	_jc_java_nio_charset_CoderResult__242$object;

typedef const struct _jc_java_nio_charset_CoderResult__242$vmethods	_jc_java_nio_charset_CoderResult__242$vmethods;
typedef const struct _jc_java_nio_charset_CoderResult__242$vtable	_jc_java_nio_charset_CoderResult__242$vtable;
typedef const struct _jc_java_nio_charset_CoderResult__242$vtype	_jc_java_nio_charset_CoderResult__242$vtype;

// Constructors
extern void _jc_java_nio_charset_CoderResult__242$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_charset_CoderResult__242$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_java_nio_charset_CoderResult__242$method$make$f3cbfffb1f7afd3c(_jc_env *, struct _jc_java_nio_charset_CoderResult__242$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_CoderResult__242$method_info$make$f3cbfffb1f7afd3c;

// Virtual methods structure
struct _jc_java_nio_charset_CoderResult__242$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*make$f3cbfffb1f7afd3c)(_jc_env *, struct _jc_java_nio_charset_CoderResult__242$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_charset_CoderResult__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CoderResult__24Cache$vmethods	java_nio_charset_CoderResult__24Cache;
	_jc_java_nio_charset_CoderResult__242$vmethods	java_nio_charset_CoderResult__242;
};

// Vtype
struct _jc_java_nio_charset_CoderResult__242$vtype {
	_jc_type			type;
	_jc_java_nio_charset_CoderResult__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_CoderResult__242$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_CoderResult__242$refs {
    _jc_java_nio_charset_CoderResult__242$sub_refs	java_nio_charset_CoderResult__242;
    _jc_java_nio_charset_CoderResult__24Cache$sub_refs	java_nio_charset_CoderResult__24Cache;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_CoderResult__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_CoderResult__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CoderResult__24Cache$sub_nonrefs	java_nio_charset_CoderResult__24Cache;
    _jc_java_nio_charset_CoderResult__242$sub_nonrefs	java_nio_charset_CoderResult__242;
};

// Object instance structure
struct _jc_java_nio_charset_CoderResult__242$object {
	_jc_java_nio_charset_CoderResult__242$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_CoderResult__242$vtype	*vtype;
	_jc_java_nio_charset_CoderResult__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_CoderResult__242$vtype _jc_java_nio_charset_CoderResult__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_CoderResult__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_CoderResult__242$class_object;

#endif	/* _JC_java_nio_charset_CoderResult__242_H_ */
